@@ -142,9 +142,10 @@ const unsigned char * const builtins[]=
 		"\\i \\i go to \\uhttp://sf.net/projects/joe-editor/\\u for upstream bug reports. JUPP 2.8 \\i \\i\n"
 		"\\i \\i for DOS compiled by A. Totlis, packed with LHarc 2.13; JUPP 3.x for UNIX\\d(R)\\d \\i \\i\n"
 		"\\i \\i at \\uhttp://mirbsd.de/jupp\\u and by \\bThorsten \"\\dmirabilos\\d\" Glaser <\\utg@mirbsd.org\\u>\\b \\i \\i\n"
-		"\\i \\i @(#) blt_in 2013-01-05; 3.1; autoCR-LF; UTF-8 via locale; per-file encoding \\i \\i\n"
+		"\\i \\i @(#) blt_in 2013-11-07; 3.1; autoCR-LF; UTF-8 via locale; per-file encoding \\i \\i\n"
 		"}\n"
 		"\n"
+		"\n"
 		"{CharTable\n"
 		"\\i   Help Screen    turn off with ^J     prev. screen ^[,    \\uCharacter Map\\u       \\i\n"
 		"\\i \\i Dec Hex  \\u 0123 4567  89AB CDEF    0123 4567  89AB CDEF \\u  Hex Dec            \\i \\i\n"
@@ -216,6 +217,14 @@ const unsigned char * const builtins[]=
 		"helpcard,rtn,keymap,\"main\",rtn,msg,rtn	^[ [ 2 0 1 ~\n"
 		"helpcard,rtn,keymap,\"main\",rtn		^D\n"
 		"\n"
+		":Pasteprompt\n"
+		"type					^@ TO \xFF\n"
+		"nop					^L\n"
+		"keymap,\"prompt\",rtn,msg,rtn,rtn		^M\n"
+		"msg,\"Entered bracketed paste mode\",rtn	^[ [ 2 0 0 ~\n"
+		"keymap,\"prompt\",rtn,msg,rtn		^[ [ 2 0 1 ~\n"
+		"keymap,\"prompt\",rtn			^D\n"
+		"\n"
 		":main\n"
 		":inherit windows\n"
 		"bof,qrepl,\"\\\\[\",quote,\"i\",quote,\"k\",quote,\"l\",quote,\"m ]\\\\+\\\\[\",quote,\"i\",quote,\"k\",quote,\"l\",quote,\"m ]\\\\$\",rtn,rtn,rtn,\"r\",eof	^K ]\n"
@@ -224,6 +233,7 @@ const unsigned char * const builtins[]=
 		"helpcard,\"Paste\",rtn,keymap,\"Paste\",rtn	^[ P\n"
 		"helpcard,\"Paste\",rtn,keymap,\"Paste\",rtn	^[ p\n"
 		"helpcard,\"Paste\",rtn,keymap,\"Paste\",rtn	^[ [ 2 0 0 ~\n"
+		"nop					^[ [ 2 0 1 ~\n"
 		"begin_marking,uparw,toggle_marking	^[ [ 1 ; 2 A\n"
 		"begin_marking,dnarw,toggle_marking	^[ [ 1 ; 2 B\n"
 		"begin_marking,rtarw,toggle_marking	^[ [ 1 ; 2 C\n"
@@ -455,6 +465,10 @@ const unsigned char * const builtins[]=
 		":inherit main\n"
 		"abort		^C\n"
 		"complete	^I\n"
+		"nop		^L\n"
+		"keymap,\"Pasteprompt\",rtn,msg,\"Entered bracketed paste mode\",rtn	^[ P\n"
+		"keymap,\"Pasteprompt\",rtn,msg,\"Entered bracketed paste mode\",rtn	^[ p\n"
+		"keymap,\"Pasteprompt\",rtn,msg,\"Entered bracketed paste mode\",rtn	^[ [ 2 0 0 ~\n"
 		"\n"
 		":menu\n"
 		":inherit windows\n"
@@ -518,5 +532,5 @@ const unsigned char * const builtins[]=
 		":querysr\n"
 		"type		^@ TO \xFF\n"
 ,	NULL
-,	"@(#) $MirOS: contrib/code/jupp/builtins.c,v 1.16 2013/01/05 22:16:29 tg Exp $"
+,	"@(#) $MirOS: contrib/code/jupp/builtins.c,v 1.18 2013/11/07 22:19:02 tg Exp $"
 };
