@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/termidx.c,v 1.3 2009/10/18 16:06:30 tg Exp $ */
+/* $MirOS: contrib/code/jupp/termidx.c,v 1.4 2012/06/08 17:05:12 tg Exp $ */
 /*
  *	Program to generate termcap index file
  *	Copyright
@@ -15,7 +15,7 @@
 static void gen(unsigned char *s, FILE *fd)
 {
 	int c, x;
-	long addr = 0, oaddr;
+	off_t addr = 0, oaddr;
 
       loop:
 	while (c = getc(fd), c == ' ' || c == '\t' || c == '#')
@@ -27,7 +27,7 @@ static void gen(unsigned char *s, FILE *fd)
 	if (c == '\n')
 		goto loop;
 	oaddr = addr;
-	addr = ftell(fd) - 1;
+	addr = ftello(fd) - 1;
 	ungetc(c, fd);
 	s[x = 0] = 0;
 	while (1) {
@@ -55,7 +55,8 @@ static void gen(unsigned char *s, FILE *fd)
 					z = y + 1;
 				} while (c && c != ':');
 				if (flg)
-					printf(" %lX\n", addr - oaddr);
+					printf(" %lX\n",
+					    (unsigned long)(addr - oaddr));
 			}
 			goto loop;
 		} else if (c == '\r')
