@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/w.c,v 1.2 2008/05/13 13:08:32 tg Exp $ */
+/* $MirOS: contrib/code/jupp/w.c,v 1.5 2012/12/30 21:45:18 tg Exp $ */
 /*
  *	Window system
  *	Copyright
@@ -301,6 +301,9 @@ void wfit(SCREEN *t)
 		} while (w != t->topwin && w->main == w->link.prev->main);
 	} while (w != t->topwin && left >= FITHEIGHT);
 
+	if (!pw)
+		return;
+
 	/* We can't use extra space to fit a new family on, so give space to parent of
 	 * previous family */
 	pw->nh += left;
@@ -489,7 +492,7 @@ void wshowall(SCREEN *t)
 	} while (w != t->topwin);
 
 	/* Compute size to set each window */
-	if ((set = (t->h - t->wind) / n) < FITHEIGHT)
+	if ((set = (t->h - t->wind) / (n ? n : 1)) < FITHEIGHT)
 		set = FITHEIGHT;
 
 	/* Set size of each variable size window */
@@ -609,7 +612,7 @@ W *wcreate(SCREEN *t, WATOM *watom, W *where, W *target, W *original, int height
 
 	/* Create new keyboard handler for window */
 	if (watom->context)
-		new->kbd = mkkbd(kmap_getcontext(watom->context));
+		new->kbd = mkkbd(kmap_getcontext(watom->context, 1));
 	else
 		new->kbd = NULL;
 
@@ -703,7 +706,7 @@ int wabort(W *w)
 
 /* Display a message and skip the next key */
 
-static void mdisp(SCRN *t, int y, unsigned char *s)
+static void mdisp(SCRN *t, int y, const unsigned char *s)
 {
 	int ofst;
 	int len;
@@ -723,11 +726,11 @@ void msgout(W *w)
 
 	if (w->msgb) {
 		mdisp(t, w->y + w->h - 1, w->msgb);
-		w->msgb = 0;
+		w->msgb = NULL;
 	}
 	if (w->msgt) {
 		mdisp(t, w->y + ((w->h > 1 && (w->y || !staen)) ? 1 : 0), w->msgt);
-		w->msgt = 0;
+		w->msgt = NULL;
 	}
 }
 
@@ -736,12 +739,12 @@ void msgout(W *w)
 unsigned char msgbuf[JOE_MSGBUFSIZE];
 
 /* display message on bottom line of window */
-void msgnw(W *w, unsigned char *s)
+void msgnw(W *w, const unsigned char *s)
 {
 	w->msgb = s;
 }
 
-void msgnwt(W *w, unsigned char *s)
+void msgnwt(W *w, const unsigned char *s)
 {
 	w->msgt = s;
 }
